@@ -212,6 +212,9 @@ def provision_migrate_role_stack(
 @click.option("--codebuild-role-name", default="CodeBuildRole")
 @click.option("--codebuild-role-path", default="/AWSOrganized/")
 @click.option("--ssm-parameter-prefix", default="/-AWS-Organized")
+@click.option("--scm-connection-arn")
+@click.option("--scm-full-repository-id", default="AWS-Organized-environment")
+@click.option("--scm-branch-name", default="main")
 @click.option("--output_format", default="yaml")
 @click.argument("migrate-role-arn")
 def generate_codepipeline_template(
@@ -220,6 +223,9 @@ def generate_codepipeline_template(
     codebuild_role_name: str,
     codebuild_role_path: str,
     ssm_parameter_prefix: str,
+    scm_connection_arn: str,
+    scm_full_repository_id: str,
+    scm_branch_name: str,
     output_format: str,
     migrate_role_arn: str,
 ):
@@ -229,6 +235,9 @@ def generate_codepipeline_template(
         codebuild_role_name,
         codebuild_role_path,
         ssm_parameter_prefix,
+        scm_connection_arn,
+        scm_full_repository_id,
+        scm_branch_name,
         migrate_role_arn,
     )
     if output_format.lower() == "json":
@@ -243,6 +252,9 @@ def generate_codepipeline_template(
 @click.option("--codebuild-role-name", default="AWSOrganizedCodeBuildRole")
 @click.option("--codebuild-role-path", default="/AWSOrganized/")
 @click.option("--ssm-parameter-prefix", default="/-AWS-Organized")
+@click.option("--scm-connection-arn")
+@click.option("--scm-full-repository-id", default="AWS-Organized-environment")
+@click.option("--scm-branch-name", default="main")
 @click.argument("migrate-role-arn")
 def provision_codepipeline_stack(
     codepipeline_role_name: str,
@@ -250,6 +262,9 @@ def provision_codepipeline_stack(
     codebuild_role_name: str,
     codebuild_role_path: str,
     ssm_parameter_prefix: str,
+    scm_connection_arn: str,
+    scm_full_repository_id: str,
+    scm_branch_name: str,
     migrate_role_arn: str,
 ):
     helpers.provision_codepipeline_stack(
@@ -258,6 +273,9 @@ def provision_codepipeline_stack(
         codebuild_role_name,
         codebuild_role_path,
         ssm_parameter_prefix,
+        scm_connection_arn,
+        scm_full_repository_id,
+        scm_branch_name,
         migrate_role_arn,
     )
 
